RRulePickerDropdownThemeData class

Theme data for customizing dropdown buttons in the RRulePicker widget.

Constructors

RRulePickerDropdownThemeData({bool? showUnderline, TextStyle? style, BoxDecoration? decoration, TextStyle? menuItemStyle, BoxDecoration? menuItemDecoration})
Creates a new RRulePickerDropdownThemeData with the provided styling options.
const

Properties

decoration BoxDecoration?
The decoration for the dropdown button.
final
hashCode int
The hash code for this object.
no setteroverride
The decoration for dropdown menu items.
final
The text style for dropdown menu items.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showUnderline bool?
Whether to show an underline for the dropdown.
final
style TextStyle?
The text style for the dropdown button.
final

Methods

copyWith({bool? showUnderline, TextStyle? style, BoxDecoration? decoration, TextStyle? menuItemStyle, BoxDecoration? menuItemDecoration}) RRulePickerDropdownThemeData
Creates a copy of this theme with the given fields replaced by the new values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

lerp(RRulePickerDropdownThemeData? a, RRulePickerDropdownThemeData? b, double t) RRulePickerDropdownThemeData?
Linearly interpolates between two dropdown themes.

Constants

defaultShowUnderline → const bool
defaultTopShowUnderline → const bool