copyWith method

RRulePickerDropdownThemeData copyWith({
  1. bool? showUnderline,
  2. TextStyle? style,
  3. BoxDecoration? decoration,
  4. TextStyle? menuItemStyle,
  5. BoxDecoration? menuItemDecoration,
})

Creates a copy of this theme with the given fields replaced by the new values.

If a field is not provided, the existing value is retained.

Implementation

RRulePickerDropdownThemeData copyWith({
  bool? showUnderline,
  TextStyle? style,
  BoxDecoration? decoration,
  TextStyle? menuItemStyle,
  BoxDecoration? menuItemDecoration,
}) => RRulePickerDropdownThemeData(
  showUnderline: showUnderline ?? this.showUnderline,
  style: style ?? this.style,
  decoration: decoration ?? this.decoration,
  menuItemStyle: menuItemStyle ?? this.menuItemStyle,
  menuItemDecoration: menuItemDecoration ?? this.menuItemDecoration,
);