RRulePickerHeaderThemeData class

Theme data for customizing the header of the RRulePicker widget.

Constructors

RRulePickerHeaderThemeData({bool? showHeader, TextStyle? style})
Creates a new RRulePickerHeaderThemeData with the provided styling options.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showHeader bool?
Whether to show the header.
final
style TextStyle?
The text style for the header.
final

Methods

copyWith({bool? showHeader, TextStyle? style}) RRulePickerHeaderThemeData
Creates a copy of this theme with the given fields replaced by the new values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

lerp(RRulePickerHeaderThemeData? a, RRulePickerHeaderThemeData? b, double t) RRulePickerHeaderThemeData?
Linearly interpolates between two header themes.