RRulePickerSpacing class

Theme data for customizing spacing in the RRulePicker widget.

Constructors

RRulePickerSpacing({required double row, required double column})
Creates a new RRulePickerSpacing with the provided spacing values.
const
RRulePickerSpacing.defaults({double row = 8.0, double column = 8.0})
Creates a new RRulePickerSpacing with the default spacing values.
const

Properties

column → double
The spacing between items in a column (main axis).
final
hashCode → int
The hash code for this object.
no setteroverride
row → double
The spacing between items in a row (main axis).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({double? row, double? column}) → RRulePickerSpacing
Creates a copy of this spacing with the given fields replaced by the new values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

lerp(RRulePickerSpacing? a, RRulePickerSpacing? b, double t) → RRulePickerSpacing?
Linearly interpolates between two spacing configurations.