copyWith method

RRulePickerSpacing copyWith({
  1. double? row,
  2. double? column,
})

Creates a copy of this spacing with the given fields replaced by the new values.

If a field is not provided, the existing value is retained.

Implementation

RRulePickerSpacing copyWith({double? row, double? column}) =>
    RRulePickerSpacing(row: row ?? this.row, column: column ?? this.column);