copyWith method

RRulePickerTextFieldThemeData copyWith({
  1. TextStyle? style,
  2. InputDecoration? decoration,
})

Creates a copy of this theme with the given fields replaced by the new values.

If a field is not provided, the existing value is retained.

Implementation

RRulePickerTextFieldThemeData copyWith({
  TextStyle? style,
  InputDecoration? decoration,
}) => RRulePickerTextFieldThemeData(
  style: style ?? this.style,
  decoration: decoration ?? this.decoration,
);