RRulePickerThemeData class

Theme data for customizing the appearance of the RRulePicker widget.

This class provides various styling options for different parts of the picker, including labels, padding, headers, dropdowns, text fields, and buttons.

Inheritance

Constructors

RRulePickerThemeData({TextStyle? labelStyle, EdgeInsetsGeometry? padding, RRulePickerHeaderThemeData? headerTheme, RRulePickerDropdownThemeData? dropdownTheme, RRulePickerDropdownThemeData? topDropdownTheme, RRulePickerTextFieldThemeData? textFieldTheme, ButtonStyle? segmentedButtonStyle, ButtonStyle? splitSegmentedButtonStyle})
Creates a new RRulePickerThemeData with the provided styling options.
const

Properties

Theme data for dropdown buttons in the picker.
final
hashCode int
The hash code for this object.
no setteroverride
headerTheme RRulePickerHeaderThemeData?
Theme data for the header of the picker.
final
labelStyle TextStyle?
The text style for labels in the picker.
final
padding EdgeInsetsGeometry?
The padding around the picker.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
segmentedButtonStyle ButtonStyle?
The style for segmented buttons in the picker.
final
splitSegmentedButtonStyle ButtonStyle?
The style for SplitSegmentedButton.
final
textFieldTheme RRulePickerTextFieldThemeData?
Theme data for text fields in the picker.
final
topDropdownTheme RRulePickerDropdownThemeData?
Theme data for dropdown buttons in the top section of the picker.
final
type Object
The extension's type.
no setterinherited

Methods

copyWith({TextStyle? labelStyle, EdgeInsetsGeometry? padding, RRulePickerHeaderThemeData? headerTheme, RRulePickerDropdownThemeData? dropdownTheme, RRulePickerDropdownThemeData? topDropdownTheme, RRulePickerTextFieldThemeData? textFieldTheme, ButtonStyle? segmentedButtonStyle, ButtonStyle? splitSegmentedButtonStyle, int? narrowLayoutBreakpoint}) RRulePickerThemeData
Creates a copy of this theme with the given fields replaced by the new values.
override
lerp(covariant RRulePickerThemeData? other, double t) RRulePickerThemeData
Linearly interpolates between this theme and another theme.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override