labeledSwitchTheme property

LabeledSwitchThemeData? labeledSwitchTheme
final

Theme data for labeled switch buttons. These widgets approximate the look and feel of SwitchListTile, but are actually TextButtons having Row with Text and Switch as its children.

The default is:

LabeledSwitchThemeData(
  style: TextButton.styleFrom(
    padding: LabeledSwitchThemeData.defaultPadding,
    shape: LabeledSwitchThemeData.defaultShape,
    textStyle: Theme.of(context).textTheme.bodyLarge,
    foregroundColor: Theme.of(context).colorScheme.onSurface,
  ),
)

Implementation

final LabeledSwitchThemeData? labeledSwitchTheme;