splitSegmentedButtonStyle property

ButtonStyle? splitSegmentedButtonStyle
final

The style for SplitSegmentedButton.

This is an internal Widget that by default approximates SegmentedButton.style, but with each segment being a separate InkWell with its own StadiumBorder.

The properties used by the widget buttons are:

Implementation

final ButtonStyle? splitSegmentedButtonStyle;