topDropdownTheme property
Theme data for dropdown buttons in the top section of the picker.
Implementation
final RRulePickerDropdownThemeData? topDropdownTheme;
Theme data for dropdown buttons in the top section of the picker.
final RRulePickerDropdownThemeData? topDropdownTheme;