widget library

Classes

RRulePicker
A widget that provides a user interface for creating and editing recurrence rules (RRULE).
RRulePickerController
A controller for managing the state of an RRulePicker.