RRulePicker class

A widget that provides a user interface for creating and editing recurrence rules (RRULE).

This widget allows users to select different recurrence types (daily, weekly, monthly, yearly) and configure their specific parameters. It also supports excluding specific dates from the recurrence.

Inheritance

Constructors

RRulePicker({Key? key, String initialRRule = '', String timeZone = '', bool enableExcludedDates = true, void onRRuleChanged(String)?, RRulePickerController? controller, RRulePickerThemeData? theme})
const

Properties

controller RRulePickerController?
An optional controller for managing the state of the picker.
final
enableExcludedDates bool
Whether to enable the excluded dates feature.
final
hashCode int
The hash code for this object.
no setterinherited
initialRRule String
The initial recurrence rule string to be displayed in the picker.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onRRuleChanged → void Function(String)?
Callback function called when the recurrence rule changes.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
theme RRulePickerThemeData?
The theme data for customizing the appearance of the picker.
final
timeZone String
The time zone to be used for the recurrence rule. It will not be validated by this package, but it should be a valid time zone name from the timezone package database.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

narrowLayoutBreakpoint int
Below this width, RRulePicker will apply a narrow adaptive layout.
getter/setter pair