controller property
An optional controller for managing the state of the picker.
You are responsible for disposing it.
If not provided, a new controller will be created and managed internally.
Implementation
final RRulePickerController? controller;
An optional controller for managing the state of the picker.
You are responsible for disposing it.
If not provided, a new controller will be created and managed internally.
final RRulePickerController? controller;