enableExcludedDates property
Whether to enable the excluded dates feature.
Defaults to true.
The value set in controller will take precedence over this one.
Implementation
final bool enableExcludedDates;
Whether to enable the excluded dates feature.
Defaults to true.
The value set in controller will take precedence over this one.
final bool enableExcludedDates;