onRRuleChanged property
Callback function called when the recurrence rule changes.
The callback receives the new recurrence rule string as a parameter.
Implementation
final void Function(String)? onRRuleChanged;
Callback function called when the recurrence rule changes.
The callback receives the new recurrence rule string as a parameter.
final void Function(String)? onRRuleChanged;