timeZone property

String timeZone
final

The time zone to be used for the recurrence rule. It will not be validated by this package, but it should be a valid time zone name from the timezone package database.

If not provided, the default time zone will be used, which currently means an empty string, i.e. no time zone at all.

The value set in controller takes precedence over this one, if not empty.

Implementation

final String timeZone;