copyWith method
RRulePickerDropdownThemeData
copyWith({
- bool? showUnderline,
- TextStyle? style,
- BoxDecoration? decoration,
Creates a copy of this theme with the given fields replaced by the new values.
If a field is not provided, the existing value is retained.
Implementation
RRulePickerDropdownThemeData copyWith({
bool? showUnderline,
TextStyle? style,
BoxDecoration? decoration,
TextStyle? menuItemStyle,
BoxDecoration? menuItemDecoration,
}) => RRulePickerDropdownThemeData(
showUnderline: showUnderline ?? this.showUnderline,
style: style ?? this.style,
decoration: decoration ?? this.decoration,
menuItemStyle: menuItemStyle ?? this.menuItemStyle,
menuItemDecoration: menuItemDecoration ?? this.menuItemDecoration,
);