copyWith method
Creates a copy of this theme with the given fields replaced by the new values.
If a field is not provided, the existing value is retained.
Implementation
RRulePickerHeaderThemeData copyWith({bool? showHeader, TextStyle? style}) =>
RRulePickerHeaderThemeData(
showHeader: showHeader ?? this.showHeader,
style: style ?? this.style,
);