RRulePickerTextFieldThemeData class
Theme data for customizing text fields in the RRulePicker widget.
Constructors
- RRulePickerTextFieldThemeData({TextStyle? style, InputDecoration? decoration})
-
Creates a new RRulePickerTextFieldThemeData with the provided styling
options.
const
Properties
- decoration → InputDecoration?
-
The decoration for the text field.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → TextStyle?
-
The text style for the text field.
final
Methods
-
copyWith(
{TextStyle? style, InputDecoration? decoration}) → RRulePickerTextFieldThemeData - Creates a copy of this theme with the given fields replaced by the new values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
lerp(
RRulePickerTextFieldThemeData? a, RRulePickerTextFieldThemeData? b, double t) → RRulePickerTextFieldThemeData? - Linearly interpolates between two text field themes.
Constants
- defaultDecoration → const InputDecoration