copyWith method

  1. @override
RRulePickerThemeData copyWith({
  1. TextStyle? labelStyle,
  2. EdgeInsetsGeometry? padding,
  3. RRulePickerHeaderThemeData? headerTheme,
  4. RRulePickerDropdownThemeData? dropdownTheme,
  5. RRulePickerDropdownThemeData? topDropdownTheme,
  6. RRulePickerTextFieldThemeData? textFieldTheme,
  7. ButtonStyle? segmentedButtonStyle,
  8. ButtonStyle? splitSegmentedButtonStyle,
  9. int? narrowLayoutBreakpoint,
})
override

Creates a copy of this theme with the given fields replaced by the new values.

If a field is not provided, the existing value is retained.

Implementation

@override
RRulePickerThemeData copyWith({
  TextStyle? labelStyle,
  EdgeInsetsGeometry? padding,
  RRulePickerHeaderThemeData? headerTheme,
  RRulePickerDropdownThemeData? dropdownTheme,
  RRulePickerDropdownThemeData? topDropdownTheme,
  RRulePickerTextFieldThemeData? textFieldTheme,
  ButtonStyle? segmentedButtonStyle,
  ButtonStyle? splitSegmentedButtonStyle,
  int? narrowLayoutBreakpoint,
}) => RRulePickerThemeData(
  labelStyle: labelStyle ?? this.labelStyle,
  padding: padding ?? this.padding,
  headerTheme: headerTheme ?? this.headerTheme,
  dropdownTheme: dropdownTheme ?? this.dropdownTheme,
  topDropdownTheme: topDropdownTheme ?? this.topDropdownTheme,
  textFieldTheme: textFieldTheme ?? this.textFieldTheme,
  segmentedButtonStyle: segmentedButtonStyle ?? this.segmentedButtonStyle,
  splitSegmentedButtonStyle:
      splitSegmentedButtonStyle ?? this.splitSegmentedButtonStyle,
);