splitSegmentedButtonStyle property
The style for SplitSegmentedButton.
This is an internal Widget that by default approximates SegmentedButton.style, but with each segment being a separate InkWell with its own StadiumBorder.
The properties used by the widget buttons are:
- ButtonStyle.textStyle.
- ButtonStyle.foregroundColor - used with default text style only.
- ButtonStyle.backgroundColor.
- ButtonStyle.shape.
- ButtonStyle.side - used with default shape only.
- ButtonStyle.fixedSize.
- ButtonStyle.animationDuration - used for button tap animation.
Implementation
final ButtonStyle? splitSegmentedButtonStyle;