initialRRule property
The initial recurrence rule string to be displayed in the picker.
Defaults to an empty string, which means no recurrence.
The value set in controller takes precedence over this one, if not empty.
Implementation
final String initialRRule;