RRulePickerController class

A controller for managing the state of an RRulePicker.

This controller handles the recurrence rule string and provides methods for updating it. It also manages the state of the different recurrence type pickers (daily, weekly, monthly, yearly) and the excluded dates picker.

Inheritance
Mixed-in types

Constructors

RRulePickerController({String initialRRule = '', String defaultTimeZone = ExcludedDatesController.defaultTimeZone, bool enableExcludedDates = true})
Creates a new RRulePickerController.

Properties

excludedDatesEnabled bool
Whether the excluded dates feature is enabled.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
Current recurrence rule string.
no setteroverride

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
setRRule(String rrule, {String defaultTimeZone = ExcludedDatesController.defaultTimeZone}) → void
Sets the recurrence rule string. Empty string means no time zone.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited